<?php

namespace apexl\Io\interfaces;

interface IoModuleInterface
{
    public function getName(): string;

    public function isInstalled(bool $forceRefresh = false): bool;

    public function routes();

    public function schema();
}
